@@ -18,19 +18,18 @@ DO_MYSQL_DBNAME=do_test
 DO_MYSQL_DATABASE=/${DO_MYSQL_DBNAME}
 
 mysql_install_db --no-defaults --datadir=${MYTEMP_DIR} --force --skip-name-resolve --user=${DO_MYSQL_USER}
-/usr/sbin/mysqld --no-defaults --user=${DO_MYSQL_USER} --socket=${MYSQL_UNIX_PORT} --datadir=${MYTEMP_DIR} --skip-networking &
+/usr/sbin/mysqld --no-defaults --user=${DO_MYSQL_USER} --socket=${MYSQL_UNIX_PORT} --datadir=${MYTEMP_DIR} --skip-networking --skip-grant &
 echo -n pinging mysqld.
 attempts=0
 while ! /usr/bin/mysqladmin --socket=${MYSQL_UNIX_PORT} ping ; do
-	sleep 3
-	attempts=$((attempts+1))
-	if [ ${attempts} -gt 10 ] ; then
-		echo "skipping test, mysql server could not be contacted after 30 seconds"
-		exit 0
-	fi
+  sleep 3
+  attempts=$((attempts+1))
+  if [ ${attempts} -gt 10 ] ; then
+    echo "skipping test, mysql server could not be contacted after 30 seconds"
+    exit 0
+  fi
 done
 mysql --socket=${MYSQL_UNIX_PORT} --execute "CREATE DATABASE ${DO_MYSQL_DBNAME};"
-mysql --socket=${MYSQL_UNIX_PORT} --execute "GRANT ALL PRIVILEGES ON ${DO_MYSQL_DBNAME}.* TO '${DO_MYSQL_USER}'@'localhost' IDENTIFIED BY '${DO_MYSQL_PASS}';"
 
 # Keep running so we can terminate mysqld.
 set +e
@@ -38,7 +37,10 @@ set +e
 dh_auto_install
 RC=$?
 
-/usr/bin/mysqladmin --socket=${MYSQL_UNIX_PORT} shutdown
-rm -rf ${MYTEMP_DIR}
+cleanup() {
+  /usr/bin/mysqladmin --socket=${MYSQL_UNIX_PORT} shutdown
+  rm -rf ${MYTEMP_DIR}
+}
+trap cleanup INT EXIT TERM
 
 exit $RC
